"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefaultEnumMock = getDefaultEnumMock;
exports.getDefaultScalarMock = getDefaultScalarMock;
exports.getDefaultListMock = getDefaultListMock;
exports.getDefaultMocks = void 0;

var _casual = _interopRequireDefault(require("casual"));

var _graphql = require("graphql");

var _mockList = require("./mockList");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getDefaultEnumMock(parentType, field) {
  const nullableType = (0, _graphql.getNullableType)(field.type);

  if (!(nullableType instanceof _graphql.GraphQLEnumType)) {
    return;
  }

  const values = nullableType.getValues().map(value => value.value);
  return () => values[_casual.default.integer(0, values.length - 1)];
} // TODO Use `faker` once v5 is released


const defaultScalarMocks = {
  Boolean: () => _casual.default.boolean,
  ID: () => _casual.default.uuid,
  Int: () => _casual.default.integer(-100, 100),
  Float: () => _casual.default.double(-100, 100),
  String: () => _casual.default.string
};

function getDefaultScalarMock(parentType, field) {
  const nullableType = (0, _graphql.getNullableType)(field.type);
  const scalarMock = defaultScalarMocks[nullableType.name];

  if (scalarMock) {
    return scalarMock;
  }
}

function getDefaultListMock(parentType, field) {
  const nullableType = (0, _graphql.getNullableType)(field.type);

  if (nullableType instanceof _graphql.GraphQLList) {
    return (0, _mockList.mockList)(2);
  }
}

const getDefaultMocks = [getDefaultEnumMock, getDefaultListMock, getDefaultScalarMock];
exports.getDefaultMocks = getDefaultMocks;
//# sourceMappingURL=defaultMocks.js.map